@@ -1,6 +1,6 @@
 from datetime import datetime
 from typing import Optional
-
+import random
 
 class RunningScenario(object):
 
@@ -10,6 +10,7 @@ class RunningScenario(object):
         self._modifiers = modifiers
         self._stopped_at = None
         self._options = options
+        random.seed(0)
 
     def name(self) -> str:
         return self._name
