@@ -41,7 +41,7 @@ class Simulation(object):
             print('Done')
 
         print('Stopping simulation')
-        result = self.api.stop_simulation(travel_time_ms)
+        result = self.api.stop_simulation()
         print('Successfully stopped simulation, writing results to disk: {}'.format(outputfile.split('/')[-1]))
 
         with open(outputfile, 'w') as outfile:
